const config = require('config')

const forgotPath = config.get('forgot-password.url')

const unsubscribeSlug = config.get('unsubscribe.url')

const { Email, services } = require('pubsweet-component-helper-service')

const { getEmailCopy } = require('./emailCopy')

module.exports = {
  async sendNotifications({ user, baseUrl }) {
    const email = new Email({
      type: 'system',
      content: {
        ctaLink: services.createUrl(baseUrl, forgotPath, {
          email: user.email,
          token: user.passwordResetToken,
        }),
        ctaText: 'RESET PASSWORD',
      },
    })

    sendForgotPasswordEmail({ email, baseUrl, user })
  },
}

const sendForgotPasswordEmail = ({ email, baseUrl, user }) => {
  email.toUser = {
    email: user.email,
    name: user.name,
  }

  email.content.subject = 'Forgot Password'
  email.content.unsubscribeLink = services.createUrl(baseUrl, unsubscribeSlug, {
    id: user.id,
  })
  email.content.signatureName = 'Hindawi Submission System'

  const { html, text } = email.getBody({
    body: getEmailCopy({
      emailType: 'user-forgot-password',
    }),
  })

  email.sendEmail({ html, text })
}
