import React from 'react'
import { get } from 'lodash'
import { connect } from 'react-redux'
import styled, { css } from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { actions } from 'pubsweet-client'
import { withJournal } from 'xpub-journal'
import { withRouter } from 'react-router-dom'
import { compose, withHandlers } from 'recompose'
import {
  Logo,
  AppBar,
  AppBarMenu,
  AutosaveIndicator,
} from 'pubsweet-component-faraday-ui'
import { userNotConfirmed } from 'pubsweet-component-faraday-selectors'
import { createDraftSubmission } from 'pubsweet-component-wizard/src/redux/conversion'

const App = ({
  autosave,
  journal = {},
  goTo,
  children,
  logout,
  currentUser,
  ...rest
}) => (
  <Root className="faraday-root">
    <AppBar
      autosave={() => (
        <AutosaveIndicator
          autosave={autosave}
          delay={5000}
          successText="Progress Saved"
        />
      )}
      currentUser={currentUser}
      journal={journal}
      logo={() => (
        <Logo
          height={54}
          onClick={() => goTo('/')}
          src={get(journal, 'metadata.logo')}
          title="Hindawi"
        />
      )}
      menu={() => (
        <AppBarMenu currentUser={currentUser} goTo={goTo} logout={logout} />
      )}
      {...rest}
    />
    <MainContainer
      canCreateDraft={rest.canCreateDraft}
      className="faraday-main"
    >
      {children}
    </MainContainer>
  </Root>
)

export default compose(
  withRouter,
  withJournal,
  connect(
    state => ({
      autosave: state.autosave,
      currentUser: state.currentUser,
      canCreateDraft: !userNotConfirmed(state),
    }),
    (dispatch, { history }) => ({
      logout: () => dispatch(actions.logoutUser()),
      createDraft: () => dispatch(createDraftSubmission(history)),
    }),
  ),
  withHandlers({
    goTo: ({ history }) => path => {
      history.push(path)
    },
  }),
)(App)

// #region styles
const Root = styled.div`
  height: 100%;
  overflow-y: auto;
  div[open] {
    width: auto;
  }
`

const appBarPaddingHelper = props =>
  props.canCreateDraft
    ? css`
        padding: calc(${th('appBar.height')} + ${th('gridUnit')})
          calc(${th('gridUnit')} * 12) calc(${th('gridUnit')} * 2);

        @media (max-width: 1200px) {
          padding: calc(${th('appBar.height')} + ${th('gridUnit')})
            calc(${th('gridUnit')} * 2) calc(${th('gridUnit')} * 2);
        }
      `
    : css`
        padding: calc(${th('appBar.height')} + ${th('gridUnit')} * 4)
          calc(${th('gridUnit')} * 12) calc(${th('gridUnit')} * 2);

        @media (max-width: 1200px) {
          padding: calc(${th('appBar.height')} + ${th('gridUnit')} * 4)
            calc(${th('gridUnit')} * 2) calc(${th('gridUnit')} * 2);
        }
      `

const MainContainer = styled.div`
  display: flex;
  flex-direction: column;
  overflow-y: auto;
  ${appBarPaddingHelper};
`
// #endregion
